# -*- coding: utf-8 -*-

from lib.access_auth import permission_needed
from django.shortcuts import render, get_object_or_404, redirect
from portailuser.models import PortailUser
from django.contrib.sessions.models import Session
from datetime import datetime, timedelta

from club.models import Club, ArticleBlog
from portailuser.app_logger import AppLogger


# Logs
_logger = AppLogger("gestion_accueil")


@permission_needed("gerer_accueil")
def liste_validation(request):
    c = {"articles": ArticleBlog.objects.filter(club__ecole=request.ecole, demande_accueil=True, sur_accueil=False)}

    return render(request, "gestion/accueil/liste_validation.html", c)


@permission_needed("gerer_accueil")
def verifier_article(request, club_id, adresse):
    club = get_object_or_404(Club, ecole=request.ecole, ident=club_id)
    article = get_object_or_404(ArticleBlog, club=club, adresse=adresse)

    if not article.demande_accueil or article.sur_accueil:
        return redirect("gestion:accueil:liste_validation")

    if request.method == "POST":
        if "valider" in request.POST:
            article.sur_accueil = True
            article.demande_accueil = False
            article.save()
            _logger.log(
                request.user,
                "A validé l'article « {} » du club {}",
                article.titre,
                article.club,
            )
            return redirect("gestion:accueil:liste_validation")

        elif "rejeter" in request.POST:
            article.sur_accueil = False
            article.demande_accueil = False
            article.save()
            _logger.log(
                request.user,
                "A rejeté l'article « {} » du club {}",
                article.titre,
                article.club,
            )
            return redirect("gestion:accueil:liste_validation")

    c = {
        "article": article,
    }

    return render(request, "gestion/accueil/verifier_article.html", c)


@permission_needed("enligne")
def enligne(request):
    sessions = Session.objects.filter(expire_date__gte=datetime.now())
    users_id = []

    for session in sessions:
        data = session.get_decoded()
        if "_auth_user_id" in data:
            users_id.append(data["_auth_user_id"])

    current_users = PortailUser.objects.filter(id__in=users_id, last_login__gt=datetime.now() - timedelta(1)).order_by(
        "-last_login"
    )
    c = {"current_users": current_users}
    return render(request, "gestion/accueil/enligne.html", c)
